#ifndef INDEXMANAGER_H
#define INDEXMANAGER_H


class IndexManager
{
    public:
        IndexManager();
        virtual ~IndexManager();

        static IndexManager* indexManager;
    protected:
    private:
};

#endif // INDEXMANAGER_H
