#ifndef DJONDB_CLIENT_H_INCLUDED
#define DJONDB_CLIENT_H_INCLUDED

#define DJONDB_CLIENT
#include "bson.h"
#include "util.h"
#include "djondbconnection.h"
#include "djondbconnectionmanager.h"


#endif // DJONDB_CLIENT_H_INCLUDED
